clear all
set mem 100m
cd  "C:\CFolderSIGEPapercounterfactuals\QE Revision 2017\Analysis\CF2\
about

use ParentsKidsData_QE_Revision_CF2_withLabels.dta,clear

tab IsParents
// generate variables to calculate the earnings of children (or female spouse of the child)
//  and mothers
// this way since the first individual is female always

// (1) first the fixed effects
/*
black 0
female
HS
SC
COL
blackHS 0
blackSC 0
blackCOL 0
femaleHS
femaleSC
femaleCOL
_cons
*/
//-----------------------------------
gen black = bind == 1
gen HS = (eind >= 2)
gen SC = (eind >= 3)
gen COL = (eind == 4)
gen blackHS = HS * black
gen blackSC = SC * black
gen blackCOL = COL * black
gen femaleHS = find * HS
gen femaleSC = find * SC
gen femaleCOL = find * COL

gen HSsp = (e >= 2)
gen SCsp = (e >= 3)
gen COLsp = (e == 4)
gen blackHSsp = HSsp * black
gen blackSCsp = SCsp * black
gen blackCOLsp = COLsp * black


gen FixEffectFemale = 0.245805 - 0.223282*black + 0.045136*blackHS + 0.037367*blackSC + 0.004705*blackCOL ///
-0.503335*find + 0.096693*HS - 0.022280*SC - 0.098633*COL - 0.044536*femaleHS + 0.048207*femaleSC + 0.044401*femaleCOL
gen FixEffectMale = 0.245805 - 0.223282*black + 0.045136*blackHSsp + 0.037367*blackSCsp + 0.004705*blackCOLsp ///
-0.503335*0 + 0.096693*HSsp - 0.022280*SCsp - 0.098633*COLsp
//-----------------------------------

gen age2 = ageind^2
gen ALHS = (eind == 1) * ageind
gen AHS = (eind >= 2) * ageind
gen ASC = (eind >= 3) * ageind
gen ACOL = (eind == 4) * ageind
gen fullwork = (laborsupply == 2)
gen femalefullwork = fullwork * find
gen fullwork1 = (dw1ind == 2)
gen fullwork2 = (dw2ind == 2)
gen fullwork3 = (dw3ind == 2)
gen fullwork4 = (dw4ind == 2)
gen partwork1 = (dw1ind == 1)
gen partwork2 = (dw2ind == 1)
gen partwork3 = (dw3ind == 1)
gen partwork4 = (dw4ind == 1)
gen femalefullwork1 = fullwork1 * find
gen femalefullwork2 = fullwork2 * find
gen femalefullwork3 = fullwork3 * find
gen femalefullwork4 = fullwork4 * find
gen femalepartwork1 = partwork1 * find
gen femalepartwork2 = partwork2 * find
gen femalepartwork3 = partwork3 * find
gen femalepartwork4 = partwork4 * find
// male spouse variables 
gen age2sp = age^2
gen ALHSsp = (e == 1) * age
gen AHSsp = (e >= 2) * age
gen ASCsp = (e >= 3) * age
gen ACOLsp = (e == 4) * age
gen fullworksp = (Slaborsupply == 2)
//gen femalefullwork = fullwork * find this is 0
gen fullwork1sp = (dw1 == 2)
gen fullwork2sp = (dw2 == 2)
gen fullwork3sp = (dw3 == 2)
gen fullwork4sp = (dw4 == 2)
gen partwork1sp = (dw1 == 1)
gen partwork2sp = (dw2 == 1)
gen partwork3sp = (dw3 == 1)
gen partwork4sp = (dw4 == 1)
/*
gen femalefullwork1 = fullwork1 * find these are 0
gen femalefullwork2 = fullwork2 * find
gen femalefullwork3 = fullwork3 * find
gen femalefullwork4 = fullwork4 * find
gen femalepartwork1 = partwork1 * find
gen femalepartwork2 = partwork2 * find
gen femalepartwork3 = partwork3 * find
gen femalepartwork4 = partwork4 * find
*/
//----------------------------------------------------

gen FemaleIncome_step1 = 8.080200 - 0.000436*age2 + 0.037700*ALHS + 0.041630*AHS + 0.004918*ASC + 0.009689*ACOL + 0.934329*fullwork - 0.119946*femalefullwork + 0.155567*fullwork1 +  0.042367*fullwork2 + 0.026121*fullwork3 + 0.039748*fullwork4 - 0.088407*partwork1 -  0.076763*partwork2 - 0.073884*partwork3 - 0.011679*partwork4 + 0.112425*femalefullwork1 +  0.026410*femalefullwork2 + 0.009968*femalefullwork3 + 0.015371*femalefullwork4 +  0.146793*femalepartwork1 + 0.056544*femalepartwork2 + 0.040698*femalepartwork3 - 0.001312*femalepartwork4
gen MaleIncome_step1 = 8.080200 - 0.000436*age2sp + 0.037700*ALHSsp + 0.041630*AHSsp + 0.004918*ASCsp  + 0.009689*ACOLsp + 0.934329*fullworksp - 0.119946*0 + 0.155567*fullwork1sp + 0.042367*fullwork2sp + 0.026121*fullwork3sp + 0.039748*fullwork4sp - 0.088407*partwork1sp - 0.076763*partwork2sp - 0.073884*partwork3sp - 0.011679*partwork4sp


gen FemaleIncome = exp(FemaleIncome_step1 + FixEffectFemale)
gen MaleIncome = exp(MaleIncome_step1 + FixEffectMale)

replace FemaleIncome = 0 if laborsupply == 0
replace MaleIncome = 0 if Slaborsupply == 0

gen FamilyIncome = FemaleIncome + MaleIncome
gen IndvIncome = .
replace IndvIncome = FemaleIncome if Cfemale == 1
replace IndvIncome = MaleIncome if Cfemale == 0

//***************************************************************************************
// Measure for Generation Family Income
//***************************************************************************************

//---------------------------------------------------------------------------------------
// MEASURE 1
//gen FamilyIncomeParentsat35 = .
//gen FamilyIncomeChildat35 = .
// keep the measure only for age 30
gen FamilyIncomeat35 = FamilyIncome if ageind == 35
gen IndvIncomeat35 = IndvIncome if ageind == 35
gen FatherIncomeat35 = MaleIncome if ageind == 35 & Cfemale == .
gen MotherIncomeat35 = FemaleIncome if ageind == 35 & Cfemale == .
//---------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------
// MEASURE 2
//gen FamilyIncomeParentsat30_40 = .
//gen FamilyIncomeChildat30_40 = .
sort idind ageind
by idind : egen FamilyIncomeat30_40 = mean(FamilyIncome) if ageind >= 30 & ageind <= 40
// keep the measure only for age 35
replace FamilyIncomeat30_40 = . if ageind != 35
//---------------------------------------------------------------------------------------
by idind : egen IndvIncomeat30_40 = mean(IndvIncome) if ageind >= 30 & ageind <= 40
// keep the measure only for age 30
replace IndvIncomeat30_40 = . if ageind != 35
//---------------------------------------------------------------------------------------
by idind : egen FatherIncomeat30_40 = mean(MaleIncome) if ageind >= 30 & ageind <= 40 & Cfemale == .
// keep the measure only for age 30
replace FatherIncomeat30_40 = . if ageind != 35
//---------------------------------------------------------------------------------------
by idind : egen MotherIncomeat30_40 = mean(FemaleIncome) if ageind >= 30 & ageind <= 40 & Cfemale == .
// keep the measure only for age 30
replace MotherIncomeat30_40 = . if ageind != 35
//---------------------------------------------------------------------------------------


//---------------------------------------------------------------------------------------
// MEASURE 3
scalar discountfactor = 0.8131835
//gen FamilyIncomeParentsLC = .
//gen FamilyIncomeChildLC = .
gen FamilyIncomeLC = .
sort idind ageind
by idind : replace FamilyIncomeLC = FamilyIncome if ageind == 25
by idind : replace FamilyIncomeLC = FamilyIncomeLC[_n-1] + (discountfactor^(_n-1))*FamilyIncome if _n > 1
// keep the measure only for age 55 which is already the correct case
replace FamilyIncomeLC = . if ageind != 55
by idind: replace FamilyIncomeLC = FamilyIncomeLC[_N] if ageind == 35
replace FamilyIncomeLC = . if ageind != 35
//---------------------------------------------------
gen IndvIncomeLC = .
sort idind ageind
by idind : replace IndvIncomeLC = IndvIncome if ageind == 25
by idind : replace IndvIncomeLC = IndvIncomeLC[_n-1] + (discountfactor^(_n-1))*IndvIncome if _n > 1
// keep the measure only for age 55 which is already the correct case
replace IndvIncomeLC = . if ageind != 55
by idind: replace IndvIncomeLC = IndvIncomeLC[_N] if ageind == 35
replace IndvIncomeLC = . if ageind != 35
//----------------------------------------------------
gen FatherIncomeLC = .
sort idind ageind
by idind : replace FatherIncomeLC = MaleIncome if ageind == 25 & Cfemale == .
by idind : replace FatherIncomeLC = FatherIncomeLC[_n-1] + (discountfactor^(_n-1))*MaleIncome if _n > 1 & Cfemale == .
// keep the measure only for age 55 which is already the correct case
replace FatherIncomeLC = . if ageind != 55
by idind: replace FatherIncomeLC = FatherIncomeLC[_N] if ageind == 35
replace FatherIncomeLC = . if ageind != 35
//---------------------------------------------------------------------------------------
gen MotherIncomeLC = .
sort idind ageind
by idind : replace MotherIncomeLC = FemaleIncome if ageind == 25 & Cfemale == .
by idind : replace MotherIncomeLC = MotherIncomeLC[_n-1] + (discountfactor^(_n-1))*FemaleIncome if _n > 1 & Cfemale == .
// keep the measure only for age 55 which is already the correct case
replace MotherIncomeLC = . if ageind != 55
by idind: replace MotherIncomeLC = MotherIncomeLC[_N] if ageind == 35
replace MotherIncomeLC = . if ageind != 35
//---------------------------------------------------------------------------------------


//---------------------------------------------------------------------------------------
//measure 4
scalar discountfactor = 0.8131835
gen FamilyIncomeLC2 = .
sort idind ageind
by idind : replace FamilyIncomeLC2 = FamilyIncome if ageind == 35
by idind : replace FamilyIncomeLC2 = FamilyIncomeLC2[_n-1] + (discountfactor^(_n-1))*FamilyIncome if ageind > 35
// keep the measure only for age 55 which is already the correct case
replace FamilyIncomeLC2 = . if ageind != 55
by idind: replace FamilyIncomeLC2 = FamilyIncomeLC2[_N] if ageind == 35
replace FamilyIncomeLC2 = . if ageind != 35
//---------------------------------------------------
gen IndvIncomeLC2 = .
sort idind ageind
by idind : replace IndvIncomeLC2 = IndvIncome if ageind == 35
by idind : replace IndvIncomeLC2 = IndvIncomeLC2[_n-1] + (discountfactor^(_n-1))*IndvIncome if ageind > 35
// keep the measure only for age 55 which is already the correct case
replace IndvIncomeLC2 = . if ageind != 55
by idind: replace IndvIncomeLC2 = IndvIncomeLC2[_N] if ageind == 35
replace IndvIncomeLC2 = . if ageind != 35
//----------------------------------------------------
gen FatherIncomeLC2 = .
sort idind ageind
by idind : replace FatherIncomeLC2 = MaleIncome if ageind == 35 & Cfemale == .
by idind : replace FatherIncomeLC2 = FatherIncomeLC2[_n-1] + (discountfactor^(_n-1))*MaleIncome if ageind > 35 & Cfemale == .
// keep the measure only for age 55 which is already the correct case
replace FatherIncomeLC2 = . if ageind != 55
by idind: replace FatherIncomeLC2 = FatherIncomeLC2[_N] if ageind == 35
replace FatherIncomeLC2 = . if ageind != 35
//---------------------------------------------------------------------------------------
gen MotherIncomeLC2 = .
sort idind ageind
by idind : replace MotherIncomeLC2 = FemaleIncome if ageind == 35 & Cfemale == .
by idind : replace MotherIncomeLC2 = MotherIncomeLC2[_n-1] + (discountfactor^(_n-1))*FemaleIncome if ageind > 35 & Cfemale == .
// keep the measure only for age 55 which is already the correct case
replace MotherIncomeLC2 = . if ageind != 55
by idind: replace MotherIncomeLC2 = MotherIncomeLC2[_N] if ageind == 35
replace MotherIncomeLC2 = . if ageind != 35
//---------------------------------------------------------------------------------------


//---------------------------------------------------------------------------------------
gen numberofLCKids = .
by idind: replace numberofLCKids = nclag[_N]
gen numberofLCFemKids = .
by idind: replace numberofLCFemKids = numfemalec[_N]

save ParentsKidsData_QE_Revision_CF2_withLabelsStep1.dta,replace


use ParentsKidsData_QE_Revision_CF2_withLabelsStep1.dta,clear
keep if IsParents == 1
keep if ageind == 35
sort idind ageind
drop ParentsID
rename idind ParentsID
keep eind e ParentsID FamilyIncomeat35 FamilyIncomeat30_40 FamilyIncomeLC FamilyIncomeLC2 numberofLCKids numberofLCFemKids FatherIncomeat35 FatherIncomeat30_40 FatherIncomeLC FatherIncomeLC2 MotherIncomeat35 MotherIncomeat30_40 MotherIncomeLC MotherIncomeLC2
rename eind educmother
rename e educfather
rename numberofLCKids numberofLCKids_Par
rename numberofLCFemKids numberofLCFemKids_Par
 
sort ParentsID
save ParentsKidsData_QE_Revision_CF2_withLabelsParents.dta,replace

//use ParentsKidsData_QE_Revision_CF2_withLabelsParents.dta,clear


use ParentsKidsData_QE_Revision_CF2_withLabelsStep1.dta,clear
keep if IsParents == 0
keep if ageind == 35
// now need to save this new file and match the parents to children
gen FamilyIncomeChildat35 = FamilyIncomeat35
gen FamilyIncomeChildat30_40 = FamilyIncomeat30_40
gen FamilyIncomeChildLC = FamilyIncomeLC
gen FamilyIncomeChildLC2 = FamilyIncomeLC2
//----------------------------------------------------
gen IndvIncomeChildat35 = IndvIncomeat35
gen IndvIncomeChildat30_40 = IndvIncomeat30_40
gen IndvIncomeChildLC = IndvIncomeLC
gen IndvIncomeChildLC2 = IndvIncomeLC2
//----------------------------------------------------
drop FamilyIncomeat35 FamilyIncomeat30_40 FamilyIncomeLC FamilyIncomeLC2 IndvIncomeat35 IndvIncomeat30_40 IndvIncomeLC IndvIncomeLC2 FatherIncomeat35 FatherIncomeat30_40 FatherIncomeLC FatherIncomeLC2 MotherIncomeat35 MotherIncomeat30_40 MotherIncomeLC MotherIncomeLC2
sort ParentsID
merge m:1 ParentsID using ParentsKidsData_QE_Revision_CF2_withLabelsParents
tab _merge
// all merged
drop _merge
sort idind
//list idind ParentsID FamilyIncomeChildat35 FamilyIncomeat35 FamilyIncomeChildat30_40 FamilyIncomeat30_40 FamilyIncomeChildLC FamilyIncomeLC

// Cfemale is the indicator for the gender of the kid under consideration



//==============================
// RANK ELASTICITY MEASURES
//==============================
// HOUSEHOLD INCOME
//-------------------------------------------------------------------------------------------------
//generate Rank Elasticities
gen SampleSize = _N

//=========================================================================================
// CHILDREN and Parents
//=========================================================================================
// measure 1
gsort FamilyIncomeChildat35    // ascending order
gen RFamilyIncomeChildat35 = _n/SampleSize

gsort FamilyIncomeat35 
gen RFamilyIncomeat35 = _n/SampleSize

// measure 2
gsort FamilyIncomeChildat30_40 
gen RFamilyIncomeChildat30_40 = _n/SampleSize

gsort FamilyIncomeat30_40 
gen RFamilyIncomeat30_40 = _n/SampleSize

// measure 3
gsort FamilyIncomeChildLC 
gen RFamilyIncomeChildLC = _n/SampleSize

gsort FamilyIncomeLC 
gen RFamilyIncomeLC = _n/SampleSize

// measure 4
gsort FamilyIncomeChildLC2
gen RFamilyIncomeChildLC2 = _n/SampleSize

gsort FamilyIncomeLC2 
gen RFamilyIncomeLC2 = _n/SampleSize


//-------------------------------------------------------------------------------------------------
// INDIVIDUAL INCOME
//-------------------------------------------------------------------------------------------------
//=========================================================================================
// CHILDREN and Parents
//=========================================================================================
//generate Rank Elasticities
set more off 
list idind ageind IndvIncomeChildat35 IndvIncomeChildat30_40 IndvIncomeChildLC Cfemale SampleSize  in 1/25

sum IndvIncomeChildat35 FatherIncomeat35 MotherIncomeat35

// measure 1
gsort IndvIncomeChildat35 
gen RIndvIncomeChildat35 = _n/SampleSize

gsort FatherIncomeat35 
gen RFatherIncomeat35 = _n/SampleSize

gsort MotherIncomeat35 
gen RMotherIncomeat35 = _n/SampleSize

// measure 2
gsort IndvIncomeChildat30_40 
gen RIndvIncomeChildat30_40 = _n/SampleSize

gsort FatherIncomeat30_40 
gen RFatherIncomeat30_40 = _n/SampleSize

gsort MotherIncomeat30_40 
gen RMotherIncomeat30_40 = _n/SampleSize

// measure 3
gsort IndvIncomeChildLC 
gen RIndvIncomeChildLC = _n/SampleSize

gsort FatherIncomeLC 
gen RFatherIncomeLC = _n/SampleSize

gsort MotherIncomeLC 
gen RMotherIncomeLC = _n/SampleSize

// measure 4
gsort IndvIncomeChildLC2
gen RIndvIncomeChildLC2 = _n/SampleSize

gsort FatherIncomeLC2 
gen RFatherIncomeLC2 = _n/SampleSize

gsort MotherIncomeLC2 
gen RMotherIncomeLC2 = _n/SampleSize

//==========================================================================================


//***************************************************
// ANALYSIS
//***************************************************

//========================
// (B) RANK TRANSITIONS 
//========================
// HOUSEHOLD INCOME
//------------------------
// fathers and sons
//------------------------
// measure 1
//------------------------
gen bottom20_M1 = 0
replace bottom20_M1 = 1 if RFamilyIncomeat35 <= 0.20
gen top20_M1 = 0
replace top20_M1 = 1 if RFamilyIncomeat35 > 0.80
//------------------------------------------------------------------
gen Median_CM1 = 0
replace Median_CM1 = 1 if RFamilyIncomeChildat35 > 0.50

table bottom20_M1 Median_CM1,contents(freq)
table top20_M1 Median_CM1,contents(freq)
//------------------------------------------------------------------------------


//------------------------
// measure 2
//------------------------
gen bottom20_M2 = 0
replace bottom20_M2 = 1 if RFamilyIncomeat30_40 <= 0.20
gen top20_M2 = 0
replace top20_M2 = 1 if RFamilyIncomeat30_40 > 0.80
//------------------------------------------------------------------
gen Median_CM2 = 0
replace Median_CM2 = 1 if RFamilyIncomeChildat30_40 > 0.50

table bottom20_M2 Median_CM2,contents(freq)
table top20_M2 Median_CM2,contents(freq)
//------------------------------------------------------------------------------


//------------------------
// measure 3
//------------------------
gen bottom20_M3 = 0
replace bottom20_M3 = 1 if RFamilyIncomeLC <= 0.20
gen top20_M3 = 0
replace top20_M3 = 1 if RFamilyIncomeLC > 0.80
//------------------------------------------------------------------
gen Median_CM3 = 0
replace Median_CM3 = 1 if RFamilyIncomeChildLC > 0.50


table bottom20_M3 Median_CM3,contents(freq)
table top20_M3 Median_CM3,contents(freq)
//------------------------------------------------------------------------------


//------------------------------------------------------------------------------
//------------------------
// Transition Matrix
//------------------------
//------------------------
// measure 2
//------------------------
gen Child10_M1 = 0
replace Child10_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.10
gen Child20_M1 = 0
replace Child20_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.20 & RFamilyIncomeChildat30_40 > 0.10
gen Child30_M1 = 0
replace Child30_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.30 & RFamilyIncomeChildat30_40 > 0.20
gen Child40_M1 = 0
replace Child40_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.40 & RFamilyIncomeChildat30_40 > 0.30
gen Child50_M1 = 0
replace Child50_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.50 & RFamilyIncomeChildat30_40 > 0.40
gen Child60_M1 = 0
replace Child60_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.60 & RFamilyIncomeChildat30_40 > 0.50
gen Child70_M1 = 0
replace Child70_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.70 & RFamilyIncomeChildat30_40 > 0.60
gen Child80_M1 = 0
replace Child80_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.80 & RFamilyIncomeChildat30_40 > 0.70
gen Child90_M1 = 0
replace Child90_M1 = 1 if RFamilyIncomeChildat30_40 <= 0.90 & RFamilyIncomeChildat30_40 > 0.80
gen ChildTop_M1 = 0
replace ChildTop_M1 = 1 if RFamilyIncomeChildat30_40 > 0.90


sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.10,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.20 & RFamilyIncomeat30_40 > 0.10,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.30 & RFamilyIncomeat30_40 > 0.20,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.40 & RFamilyIncomeat30_40 > 0.30,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.50 & RFamilyIncomeat30_40 > 0.40,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.60 & RFamilyIncomeat30_40 > 0.50,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.70 & RFamilyIncomeat30_40 > 0.60,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.80 & RFamilyIncomeat30_40 > 0.70,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 <= 0.90 & RFamilyIncomeat30_40 > 0.80,separator(0)
sum Child10_M1-ChildTop_M1 if RFamilyIncomeat30_40 > 0.90,separator(0)
//------------------------------------------------------------------------------



//-------------------------------------------------------------------------------
// You can work your analysis directly on this file for constructing new measures
save ParentsKidsData_QE_Revision_CF2_Mobility_Analysis.dta,replace
//--------------------------------------------------------------
use ParentsKidsData_QE_Revision_CF2_Mobility_Analysis.dta,clear
